==> aws-cdk-scala-kinesisfirehose_2.13-0.4.1-sources.jar: io/burkard/cdk/services/kinesisfirehose/OrcSerDeProperty.scala <==
package io.burkard.cdk.services.kinesisfirehose

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object OrcSerDeProperty {

  def apply(
    enablePadding: Option[Boolean] = None,
    formatVersion: Option[String] = None,
    bloomFilterFalsePositiveProbability: Option[Number] = None,
    compression: Option[String] = None,
    paddingTolerance: Option[Number] = None,
    bloomFilterColumns: Option[List[String]] = None,
    stripeSizeBytes: Option[Number] = None,
    dictionaryKeyThreshold: Option[Number] = None,
    blockSizeBytes: Option[Number] = None,
    rowIndexStride: Option[Number] = None
  ): software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.OrcSerDeProperty =
    (new software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.OrcSerDeProperty.Builder)
      .enablePadding(enablePadding.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .formatVersion(formatVersion.orNull)
      .bloomFilterFalsePositiveProbability(bloomFilterFalsePositiveProbability.orNull)
      .compression(compression.orNull)
      .paddingTolerance(paddingTolerance.orNull)
      .bloomFilterColumns(bloomFilterColumns.map(_.asJava).orNull)
      .stripeSizeBytes(stripeSizeBytes.orNull)
      .dictionaryKeyThreshold(dictionaryKeyThreshold.orNull)
      .blockSizeBytes(blockSizeBytes.orNull)
      .rowIndexStride(rowIndexStride.orNull)
      .build()
}

==> aws-cdk-scala-kinesisfirehose_3-0.1.7-sources.jar: io/burkard/cdk/services/kinesisfirehose/OrcSerDeProperty.scala <==
package io.burkard.cdk.services.kinesisfirehose

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object OrcSerDeProperty {

  def apply(
    enablePadding: Option[Boolean] = None,
    compression: Option[String] = None,
    paddingTolerance: Option[Number] = None,
    bloomFilterColumns: Option[List[String]] = None,
    stripeSizeBytes: Option[Number] = None,
    dictionaryKeyThreshold: Option[Number] = None,
    blockSizeBytes: Option[Number] = None,
    rowIndexStride: Option[Number] = None,
    formatVersion: Option[String] = None,
    bloomFilterFalsePositiveProbability: Option[Number] = None
  ): software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.OrcSerDeProperty =
    (new software.amazon.awscdk.services.kinesisfirehose.CfnDeliveryStream.OrcSerDeProperty.Builder)
      .enablePadding(enablePadding.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .compression(compression.orNull)
      .paddingTolerance(paddingTolerance.orNull)
      .bloomFilterColumns(bloomFilterColumns.map(_.asJava).orNull)
      .stripeSizeBytes(stripeSizeBytes.orNull)
      .dictionaryKeyThreshold(dictionaryKeyThreshold.orNull)
      .blockSizeBytes(blockSizeBytes.orNull)
      .rowIndexStride(rowIndexStride.orNull)
      .formatVersion(formatVersion.orNull)
      .bloomFilterFalsePositiveProbability(bloomFilterFalsePositiveProbability.orNull)
      .build()
}
